==> nextcloud-27.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da directiva de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da directiva de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "Disable-user-theming should be true or false" : "Disable-user-theming (desactivar o tema do usuario) debe ser verdadeiro ou falso",
    "Saved" : "Gardado",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "Failed to clean up the old administration theming images folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes de temas",
    "Failed to clean up the old administration image folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes da aplicación de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Appearance and accessibility" : "Aparencia e accesibilidade",
    "Dark theme with high contrast mode" : "Tema escuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semellante ao modo de alto contraste, mais con cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Activar o tema escuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema escuro para aliviar os seus ollos reducindo a luminosidade e o brillo xerais.",
    "System default theme" : "Tema predeterminado do sistema",
    "Enable the system default" : "Activar o predeterminado do sistema ",
    "Using the default system appearance." : "Usando a aparencia predeterminada do sistema.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "Enable dyslexia font" : "Activar o tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar o modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar o tema claro predeterminado",
    "The default light appearance." : "A aparencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Directiva de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Advanced options" : "Opcións avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalar a extensión PHP ImageMagick con compatibilidade con imaxes SVG para xerar automaticamente favicons baseados no logotipo e na cor cargados.",
    "Name" : "Nome",
    "Web link" : "Ligazón web",
    "a safe home for all your data" : "un lugar seguro para todos os seus datos",
    "Slogan" : "Lema",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Background and login image" : "Imaxe de fondo e acceso",
    "Upload new background and login image" : "Carga unha nova imaxe de fondo e de acceso",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á directiva de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "User settings" : "Axustes de usuario",
    "Disable user theming" : "Desactivar o tema do usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode activar esta opción.",
    "Keyboard shortcuts" : "Atallos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Disable all keyboard shortcuts" : "Desactivar todos os atallos de teclado",
    "Background" : "Fondo",
    "Customization has been disabled by your administrator" : "O seu administrador desactivou a personalización",
    "Set a custom background" : "Estabelecer un fondo personalizado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Para nós o acceso universal é moi importante. Seguimos os estándares web e comprobamos que todo poida ser utilizado sen rato e software de axuda como os lectores de pantalla. O noso obxectivo é ter cumprir ás {guidelines}Directrices de accesibilidade ao contido web{linkend}  2.1 a nivel AA, co tema de alto contraste incluso a nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se atopa algúnha incidencia, non dubide en informalo no {issuetracker}noso seguidor de incidencias{linkend} E se quere involucrarse, únase ao {designteam}noso equipo de deseño {linkend}!",
    "Custom background" : "Fondo personalizado",
    "Default background" : "Fondo predeterminado",
    "Change color" : "Cambiar a cor",
    "No background" : "Sen fondo",
    "Select a background from your files" : "Seleccione un fondo dende os seus ficheiros",
    "Theme selection is enforced" : "Aplicarase a selección do tema",
    "Select a custom color" : "Seleccione unha cor personalizada",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Upload" : "Enviar",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Loading preview…" : "Cargando a vista previa…",
    "Admin" : "Administración",
    "Error uploading the file" : "Produciuse un erro ao enviar o ficheiro",
    "Name cannot be empty" : "O nome non pode estar baleiro",
    "Migrate and clean up admin theming images" : "Migración e limpeza de imaxes de temas de administrador",
    "Failed to clean up the old admin theming images folder" : "Produciuse un erro ao limpar o antigo cartafol de imaxes de temas do administrador",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Pick from Files" : "Escolla entre os ficheiros",
    "Default image" : "Imaxe predeterminada",
    "Custom color" : "Cor personalizada",
    "Plain background" : "Fondo sinxelo",
    "Insert from {productName}" : "Inserir dende {productName}",
    "Open documentation" : "Abrir a documentación",
    "https://…" : "https://…",
    "Upload new login background" : "Enviar unha nova imaxe de fondo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode marcar esta caixa.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensión de PHP Imagemagick con compatibilidade con imaxes SVG para xerar automáticamente faviconos baseados no logotipo e cor enviados."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/gl.js <==
OC.L10N.register(
    "theming",
    {
    "The given name is too long" : "O nome indicado é longo de máis",
    "The given web address is too long" : "O enderezo web indicado é longo de máis",
    "The given web address is not a valid URL" : "O enderezo web indicado non é un URL válido",
    "The given legal notice address is too long" : "O enderezo do aviso legal indicado é longo de máis",
    "The given legal notice address is not a valid URL" : "O enderezo do aviso legal indicado non é un URL válido",
    "The given privacy policy address is too long" : "O enderezo da directiva de privacidade indicado é longo de máis",
    "The given privacy policy address is not a valid URL" : "O enderezo da directiva de privacidade indicado non é un URL válido",
    "The given slogan is too long" : "O lema indicado é longo de máis",
    "The given color is invalid" : "A cor indicada é incorrecta",
    "Disable-user-theming should be true or false" : "Disable-user-theming (desactivar o tema do usuario) debe ser verdadeiro ou falso",
    "Saved" : "Gardado",
    "The file was uploaded" : "O ficheiro foi enviado",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "O ficheiro enviado excede a directiva indicada por upload_max_filesize de php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "O ficheiro enviado excede da directiva MAX_FILE_SIZE especificada no formulario HTML",
    "The file was only partially uploaded" : "O ficheiro só foi parcialmente enviado",
    "No file was uploaded" : "Non se enviou ningún ficheiro",
    "Missing a temporary folder" : "Falta un cartafol temporal",
    "Could not write file to disk" : "Non foi posíbel escribir o ficheiro no disco",
    "A PHP extension stopped the file upload" : "Unha extensión PHP detivo o envío de ficheiros",
    "No file uploaded" : "Non se enviou ningún ficheiro",
    "Failed to clean up the old administration theming images folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes de temas",
    "Failed to clean up the old administration image folder" : "Produciuse un erro ao limpar o antigo cartafol de administración de imaxes",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Está a empregar un tema personalizado. Os axustes da aplicación de temas poden ser sobrescritos por el.",
    "Theming" : "Temas",
    "Appearance and accessibility" : "Aparencia e accesibilidade",
    "Dark theme with high contrast mode" : "Tema escuro con modo de alto contraste",
    "Enable dark high contrast mode" : "Activar o modo escuro de alto contraste",
    "Similar to the high contrast mode, but with dark colours." : "Semellante ao modo de alto contraste, mais con cores escuras.",
    "Dark theme" : "Tema escuro",
    "Enable dark theme" : "Activar o tema escuro",
    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "Un tema escuro para aliviar os seus ollos reducindo a luminosidade e o brillo xerais.",
    "System default theme" : "Tema predeterminado do sistema",
    "Enable the system default" : "Activar o predeterminado do sistema ",
    "Using the default system appearance." : "Usando a aparencia predeterminada do sistema.",
    "Dyslexia font" : "Tipo de letra para disléxicos",
    "Enable dyslexia font" : "Activar o tipo de letra para disléxicos",
    "OpenDyslexic is a free typeface/font designed to mitigate some of the common reading errors caused by dyslexia." : "OpenDyslexic é un tipo de letra libre deseñada para mitigar algúns dos erros comúns de lectura causados pola dislexia.",
    "High contrast mode" : "Modo de alto contraste",
    "Enable high contrast mode" : "Activar o modo de alto contraste",
    "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "Un modo de alto contraste para facilitar a navegación. A calidade visual será reducida, mais a claridade aumentará.",
    "Light theme" : "Tema claro",
    "Enable the default light theme" : "Activar o tema claro predeterminado",
    "The default light appearance." : "A aparencia clara predeterminada.",
    "Legal notice" : "Aviso legal",
    "Privacy policy" : "Directiva de privacidade",
    "Adjust the Nextcloud theme" : "Axustar o tema de Nextcloud",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Os temas fan posíbel personalizar facilmente a aparencia da súa instancia e os clientes compatíbeis. Isto será visíbel para todos os usuarios.",
    "Advanced options" : "Opcións avanzadas",
    "Install the ImageMagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instalar a extensión PHP ImageMagick con compatibilidade con imaxes SVG para xerar automaticamente favicons baseados no logotipo e na cor enviados.",
    "Name" : "Nome",
    "Web link" : "Ligazón web",
    "a safe home for all your data" : "un acubillo seguro para todos os seus datos",
    "Slogan" : "Lema",
    "Color" : "Cor",
    "Logo" : "Logotipo",
    "Upload new logo" : "Enviar un novo logotipo",
    "Background and login image" : "Imaxe de fondo e acceso",
    "Upload new background and login image" : "Enviar unha nova imaxe de fondo e de acceso",
    "Legal notice link" : "Ligazón ao aviso legal",
    "Privacy policy link" : "Ligazón á directiva de privacidade",
    "Header logo" : "Logotipo da cabeceira",
    "Upload new header logo" : "Enviar un novo logotipo da cabeceira",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Enviar un novo favicon",
    "User settings" : "Axustes de usuario",
    "Disable user theming" : "Desactivar o tema do usuario",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode activar esta opción.",
    "Background" : "Fondo",
    "Customization has been disabled by your administrator" : "O seu administrador desactivou a personalización",
    "Set a custom background" : "Estabelecer un fondo personalizado",
    "Keyboard shortcuts" : "Atallos de teclado",
    "In some cases keyboard shortcuts can interfere with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Disable all keyboard shortcuts" : "Desactivar todos os atallos de teclado",
    "Universal access is very important to us. We follow web standards and check to make everything usable also without mouse, and assistive software such as screenreaders. We aim to be compliant with the {guidelines}Web Content Accessibility Guidelines{linkend} 2.1 on AA level, with the high contrast theme even on AAA level." : "Para nós o acceso universal é moi importante. Seguimos os estándares web e comprobamos que todo poida ser utilizado sen rato e software de axuda como os lectores de pantalla. O noso obxectivo é ter cumprir ás {guidelines}Directrices de accesibilidade ao contido web{linkend}  2.1 a nivel AA, co tema de alto contraste incluso a nivel AAA.",
    "If you find any issues, do not hesitate to report them on {issuetracker}our issue tracker{linkend}. And if you want to get involved, come join {designteam}our design team{linkend}!" : "Se atopa algúnha incidencia, non dubide en informalo no {issuetracker}noso seguidor de incidencias{linkend} E se quere involucrarse, únase ao {designteam}noso equipo de deseño {linkend}!",
    "Move up" : "Mover cara arriba",
    "Move down" : "Mover cara abaixo",
    "Custom background" : "Fondo personalizado",
    "Default background" : "Fondo predeterminado",
    "Change color" : "Cambiar a cor",
    "No background" : "Sen fondo",
    "Select a background from your files" : "Seleccione un fondo dende os seus ficheiros",
    "Select background" : "Seleccione o fondo",
    "No background has been selected" : "Non foi seleccionado ningún fondo",
    "Theme selection is enforced" : "Imponse a selección de temas",
    "Default app" : "Aplicación predeterminada",
    "Select a custom color" : "Seleccione unha cor personalizada",
    "Reset to default" : "Restabelecer os valores predeterminados",
    "Upload" : "Enviar",
    "Remove background image" : "Retirar a imaxe de fondo",
    "Loading preview…" : "Cargando a vista previa…",
    "Admin" : "Administración",
    "Error uploading the file" : "Produciuse un erro ao enviar o ficheiro",
    "Name cannot be empty" : "O nome non pode estar baleiro",
    "Migrate and clean up admin theming images" : "Migración e limpeza de imaxes de temas de administrador",
    "Failed to clean up the old admin theming images folder" : "Produciuse un erro ao limpar o antigo cartafol de imaxes de temas do administrador",
    "In some cases keyboard shortcuts can interfer with accessibility tools. In order to allow focusing on your tool correctly you can disable all keyboard shortcuts here. This will also disable all available shortcuts in apps." : "Nalgúns casos, os atallos de teclado poden interferir coas ferramentas de accesibilidade. Para poder centrarse na súa ferramenta correctamente, pode desactivar aquí todos os atallos de teclado. Isto tamén desactivará todos os atallos dispoñíbeis nas aplicacións.",
    "Pick from Files" : "Escolla entre os ficheiros",
    "Default image" : "Imaxe predeterminada",
    "Custom color" : "Cor personalizada",
    "Plain background" : "Fondo sinxelo",
    "Insert from {productName}" : "Inserir dende {productName}",
    "Open documentation" : "Abrir a documentación",
    "https://…" : "https://…",
    "Upload new login background" : "Enviar unha nova imaxe de fondo",
    "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can check this box." : "Aínda que pode seleccionar e personalizar a súa instancia, os usuarios poden cambiar o seu fondo e cores. Se quere impor a súa personalización, pode marcar esta caixa.",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Instale a extensión de PHP Imagemagick con compatibilidade con imaxes SVG para xerar automáticamente faviconos baseados no logotipo e cor enviados."
},
"nplurals=2; plural=(n != 1);");
